@@ -111,7 +111,7 @@ class EMRContainersClient(BaseClient):
         executionRoleArn: str,
         clientToken: str,
         certificateArn: str = ...,
-        configurationOverrides: "ConfigurationOverridesTypeDef" = ...,
+        configurationOverrides: ConfigurationOverridesTypeDef = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateManagedEndpointResponseTypeDef:
         """
@@ -125,7 +125,7 @@ class EMRContainersClient(BaseClient):
         self,
         *,
         name: str,
-        containerProvider: "ContainerProviderTypeDef",
+        containerProvider: ContainerProviderTypeDef,
         clientToken: str,
         tags: Mapping[str, str] = ...
     ) -> CreateVirtualClusterResponseTypeDef:
@@ -263,9 +263,9 @@ class EMRContainersClient(BaseClient):
         clientToken: str,
         executionRoleArn: str,
         releaseLabel: str,
-        jobDriver: "JobDriverTypeDef",
+        jobDriver: JobDriverTypeDef,
         name: str = ...,
-        configurationOverrides: "ConfigurationOverridesTypeDef" = ...,
+        configurationOverrides: ConfigurationOverridesTypeDef = ...,
         tags: Mapping[str, str] = ...
     ) -> StartJobRunResponseTypeDef:
         """
