@@ -35,52 +35,52 @@ else:
 
 __all__ = (
     "CancelJobRunRequestRequestTypeDef",
-    "CancelJobRunResponseTypeDef",
+    "ResponseMetadataTypeDef",
     "CertificateTypeDef",
     "CloudWatchMonitoringConfigurationTypeDef",
-    "ConfigurationOverridesTypeDef",
     "ConfigurationTypeDef",
-    "ContainerInfoTypeDef",
-    "ContainerProviderTypeDef",
-    "CreateManagedEndpointRequestRequestTypeDef",
-    "CreateManagedEndpointResponseTypeDef",
-    "CreateVirtualClusterRequestRequestTypeDef",
-    "CreateVirtualClusterResponseTypeDef",
-    "DeleteManagedEndpointRequestRequestTypeDef",
-    "DeleteManagedEndpointResponseTypeDef",
-    "DeleteVirtualClusterRequestRequestTypeDef",
-    "DeleteVirtualClusterResponseTypeDef",
-    "DescribeJobRunRequestRequestTypeDef",
-    "DescribeJobRunResponseTypeDef",
-    "DescribeManagedEndpointRequestRequestTypeDef",
-    "DescribeManagedEndpointResponseTypeDef",
-    "DescribeVirtualClusterRequestRequestTypeDef",
-    "DescribeVirtualClusterResponseTypeDef",
     "EksInfoTypeDef",
-    "EndpointTypeDef",
-    "JobDriverTypeDef",
-    "JobRunTypeDef",
-    "ListJobRunsRequestListJobRunsPaginateTypeDef",
-    "ListJobRunsRequestRequestTypeDef",
-    "ListJobRunsResponseTypeDef",
-    "ListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
-    "ListManagedEndpointsRequestRequestTypeDef",
-    "ListManagedEndpointsResponseTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "ListVirtualClustersRequestListVirtualClustersPaginateTypeDef",
-    "ListVirtualClustersRequestRequestTypeDef",
-    "ListVirtualClustersResponseTypeDef",
-    "MonitoringConfigurationTypeDef",
-    "PaginatorConfigTypeDef",
-    "ResponseMetadataTypeDef",
-    "S3MonitoringConfigurationTypeDef",
+    "DeleteManagedEndpointRequestRequestTypeDef",
+    "DeleteVirtualClusterRequestRequestTypeDef",
+    "DescribeJobRunRequestRequestTypeDef",
+    "DescribeManagedEndpointRequestRequestTypeDef",
+    "DescribeVirtualClusterRequestRequestTypeDef",
     "SparkSubmitJobDriverTypeDef",
-    "StartJobRunRequestRequestTypeDef",
-    "StartJobRunResponseTypeDef",
+    "PaginatorConfigTypeDef",
+    "ListJobRunsRequestRequestTypeDef",
+    "ListManagedEndpointsRequestRequestTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListVirtualClustersRequestRequestTypeDef",
+    "S3MonitoringConfigurationTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
+    "CancelJobRunResponseTypeDef",
+    "CreateManagedEndpointResponseTypeDef",
+    "CreateVirtualClusterResponseTypeDef",
+    "DeleteManagedEndpointResponseTypeDef",
+    "DeleteVirtualClusterResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "StartJobRunResponseTypeDef",
+    "ContainerInfoTypeDef",
+    "JobDriverTypeDef",
+    "ListJobRunsRequestListJobRunsPaginateTypeDef",
+    "ListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
+    "ListVirtualClustersRequestListVirtualClustersPaginateTypeDef",
+    "MonitoringConfigurationTypeDef",
+    "ContainerProviderTypeDef",
+    "ConfigurationOverridesTypeDef",
+    "CreateVirtualClusterRequestRequestTypeDef",
     "VirtualClusterTypeDef",
+    "CreateManagedEndpointRequestRequestTypeDef",
+    "EndpointTypeDef",
+    "JobRunTypeDef",
+    "StartJobRunRequestRequestTypeDef",
+    "DescribeVirtualClusterResponseTypeDef",
+    "ListVirtualClustersResponseTypeDef",
+    "DescribeManagedEndpointResponseTypeDef",
+    "ListManagedEndpointsResponseTypeDef",
+    "DescribeJobRunResponseTypeDef",
+    "ListJobRunsResponseTypeDef",
 )
 
 CancelJobRunRequestRequestTypeDef = TypedDict(
@@ -91,12 +91,14 @@ CancelJobRunRequestRequestTypeDef = TypedDict(
     },
 )
 
-CancelJobRunResponseTypeDef = TypedDict(
-    "CancelJobRunResponseTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "id": str,
-        "virtualClusterId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -131,15 +133,6 @@ class CloudWatchMonitoringConfigurationTypeDef(
     pass
 
 
-ConfigurationOverridesTypeDef = TypedDict(
-    "ConfigurationOverridesTypeDef",
-    {
-        "applicationConfiguration": Sequence["ConfigurationTypeDef"],
-        "monitoringConfiguration": "MonitoringConfigurationTypeDef",
-    },
-    total=False,
-)
-
 _RequiredConfigurationTypeDef = TypedDict(
     "_RequiredConfigurationTypeDef",
     {
@@ -160,110 +153,14 @@ class ConfigurationTypeDef(_RequiredConfigurationTypeDef, _OptionalConfiguration
     pass
 
 
-ContainerInfoTypeDef = TypedDict(
-    "ContainerInfoTypeDef",
+EksInfoTypeDef = TypedDict(
+    "EksInfoTypeDef",
     {
-        "eksInfo": "EksInfoTypeDef",
+        "namespace": str,
     },
     total=False,
 )
 
-_RequiredContainerProviderTypeDef = TypedDict(
-    "_RequiredContainerProviderTypeDef",
-    {
-        "type": Literal["EKS"],
-        "id": str,
-    },
-)
-_OptionalContainerProviderTypeDef = TypedDict(
-    "_OptionalContainerProviderTypeDef",
-    {
-        "info": "ContainerInfoTypeDef",
-    },
-    total=False,
-)
-
-
-class ContainerProviderTypeDef(
-    _RequiredContainerProviderTypeDef, _OptionalContainerProviderTypeDef
-):
-    pass
-
-
-_RequiredCreateManagedEndpointRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateManagedEndpointRequestRequestTypeDef",
-    {
-        "name": str,
-        "virtualClusterId": str,
-        "type": str,
-        "releaseLabel": str,
-        "executionRoleArn": str,
-        "clientToken": str,
-    },
-)
-_OptionalCreateManagedEndpointRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateManagedEndpointRequestRequestTypeDef",
-    {
-        "certificateArn": str,
-        "configurationOverrides": "ConfigurationOverridesTypeDef",
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateManagedEndpointRequestRequestTypeDef(
-    _RequiredCreateManagedEndpointRequestRequestTypeDef,
-    _OptionalCreateManagedEndpointRequestRequestTypeDef,
-):
-    pass
-
-
-CreateManagedEndpointResponseTypeDef = TypedDict(
-    "CreateManagedEndpointResponseTypeDef",
-    {
-        "id": str,
-        "name": str,
-        "arn": str,
-        "virtualClusterId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredCreateVirtualClusterRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateVirtualClusterRequestRequestTypeDef",
-    {
-        "name": str,
-        "containerProvider": "ContainerProviderTypeDef",
-        "clientToken": str,
-    },
-)
-_OptionalCreateVirtualClusterRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateVirtualClusterRequestRequestTypeDef",
-    {
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateVirtualClusterRequestRequestTypeDef(
-    _RequiredCreateVirtualClusterRequestRequestTypeDef,
-    _OptionalCreateVirtualClusterRequestRequestTypeDef,
-):
-    pass
-
-
-CreateVirtualClusterResponseTypeDef = TypedDict(
-    "CreateVirtualClusterResponseTypeDef",
-    {
-        "id": str,
-        "name": str,
-        "arn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DeleteManagedEndpointRequestRequestTypeDef = TypedDict(
     "DeleteManagedEndpointRequestRequestTypeDef",
     {
@@ -272,15 +169,6 @@ DeleteManagedEndpointRequestRequestTypeDef = TypedDict(
     },
 )
 
-DeleteManagedEndpointResponseTypeDef = TypedDict(
-    "DeleteManagedEndpointResponseTypeDef",
-    {
-        "id": str,
-        "virtualClusterId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DeleteVirtualClusterRequestRequestTypeDef = TypedDict(
     "DeleteVirtualClusterRequestRequestTypeDef",
     {
@@ -288,14 +176,6 @@ DeleteVirtualClusterRequestRequestTypeDef = TypedDict(
     },
 )
 
-DeleteVirtualClusterResponseTypeDef = TypedDict(
-    "DeleteVirtualClusterResponseTypeDef",
-    {
-        "id": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribeJobRunRequestRequestTypeDef = TypedDict(
     "DescribeJobRunRequestRequestTypeDef",
     {
@@ -304,14 +184,6 @@ DescribeJobRunRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeJobRunResponseTypeDef = TypedDict(
-    "DescribeJobRunResponseTypeDef",
-    {
-        "jobRun": "JobRunTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribeManagedEndpointRequestRequestTypeDef = TypedDict(
     "DescribeManagedEndpointRequestRequestTypeDef",
     {
@@ -320,14 +192,6 @@ DescribeManagedEndpointRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeManagedEndpointResponseTypeDef = TypedDict(
-    "DescribeManagedEndpointResponseTypeDef",
-    {
-        "endpoint": "EndpointTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribeVirtualClusterRequestRequestTypeDef = TypedDict(
     "DescribeVirtualClusterRequestRequestTypeDef",
     {
@@ -335,104 +199,38 @@ DescribeVirtualClusterRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeVirtualClusterResponseTypeDef = TypedDict(
-    "DescribeVirtualClusterResponseTypeDef",
+_RequiredSparkSubmitJobDriverTypeDef = TypedDict(
+    "_RequiredSparkSubmitJobDriverTypeDef",
     {
-        "virtualCluster": "VirtualClusterTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "entryPoint": str,
     },
 )
-
-EksInfoTypeDef = TypedDict(
-    "EksInfoTypeDef",
+_OptionalSparkSubmitJobDriverTypeDef = TypedDict(
+    "_OptionalSparkSubmitJobDriverTypeDef",
     {
-        "namespace": str,
-    },
-    total=False,
-)
-
-EndpointTypeDef = TypedDict(
-    "EndpointTypeDef",
-    {
-        "id": str,
-        "name": str,
-        "arn": str,
-        "virtualClusterId": str,
-        "type": str,
-        "state": EndpointStateType,
-        "releaseLabel": str,
-        "executionRoleArn": str,
-        "certificateArn": str,
-        "certificateAuthority": "CertificateTypeDef",
-        "configurationOverrides": "ConfigurationOverridesTypeDef",
-        "serverUrl": str,
-        "createdAt": datetime,
-        "securityGroup": str,
-        "subnetIds": List[str],
-        "stateDetails": str,
-        "failureReason": FailureReasonType,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-JobDriverTypeDef = TypedDict(
-    "JobDriverTypeDef",
-    {
-        "sparkSubmitJobDriver": "SparkSubmitJobDriverTypeDef",
-    },
-    total=False,
-)
-
-JobRunTypeDef = TypedDict(
-    "JobRunTypeDef",
-    {
-        "id": str,
-        "name": str,
-        "virtualClusterId": str,
-        "arn": str,
-        "state": JobRunStateType,
-        "clientToken": str,
-        "executionRoleArn": str,
-        "releaseLabel": str,
-        "configurationOverrides": "ConfigurationOverridesTypeDef",
-        "jobDriver": "JobDriverTypeDef",
-        "createdAt": datetime,
-        "createdBy": str,
-        "finishedAt": datetime,
-        "stateDetails": str,
-        "failureReason": FailureReasonType,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-_RequiredListJobRunsRequestListJobRunsPaginateTypeDef = TypedDict(
-    "_RequiredListJobRunsRequestListJobRunsPaginateTypeDef",
-    {
-        "virtualClusterId": str,
-    },
-)
-_OptionalListJobRunsRequestListJobRunsPaginateTypeDef = TypedDict(
-    "_OptionalListJobRunsRequestListJobRunsPaginateTypeDef",
-    {
-        "createdBefore": Union[datetime, str],
-        "createdAfter": Union[datetime, str],
-        "name": str,
-        "states": Sequence[JobRunStateType],
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "entryPointArguments": List[str],
+        "sparkSubmitParameters": str,
     },
     total=False,
 )
 
 
-class ListJobRunsRequestListJobRunsPaginateTypeDef(
-    _RequiredListJobRunsRequestListJobRunsPaginateTypeDef,
-    _OptionalListJobRunsRequestListJobRunsPaginateTypeDef,
+class SparkSubmitJobDriverTypeDef(
+    _RequiredSparkSubmitJobDriverTypeDef, _OptionalSparkSubmitJobDriverTypeDef
 ):
     pass
 
 
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
 _RequiredListJobRunsRequestRequestTypeDef = TypedDict(
     "_RequiredListJobRunsRequestRequestTypeDef",
     {
@@ -459,41 +257,6 @@ class ListJobRunsRequestRequestTypeDef(
     pass
 
 
-ListJobRunsResponseTypeDef = TypedDict(
-    "ListJobRunsResponseTypeDef",
-    {
-        "jobRuns": List["JobRunTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef = TypedDict(
-    "_RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
-    {
-        "virtualClusterId": str,
-    },
-)
-_OptionalListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef = TypedDict(
-    "_OptionalListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
-    {
-        "createdBefore": Union[datetime, str],
-        "createdAfter": Union[datetime, str],
-        "types": Sequence[str],
-        "states": Sequence[EndpointStateType],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef(
-    _RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef,
-    _OptionalListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListManagedEndpointsRequestRequestTypeDef = TypedDict(
     "_RequiredListManagedEndpointsRequestRequestTypeDef",
     {
@@ -521,15 +284,6 @@ class ListManagedEndpointsRequestRequestTypeDef(
     pass
 
 
-ListManagedEndpointsResponseTypeDef = TypedDict(
-    "ListManagedEndpointsResponseTypeDef",
-    {
-        "endpoints": List["EndpointTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
     "ListTagsForResourceRequestRequestTypeDef",
     {
@@ -537,27 +291,6 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListVirtualClustersRequestListVirtualClustersPaginateTypeDef = TypedDict(
-    "ListVirtualClustersRequestListVirtualClustersPaginateTypeDef",
-    {
-        "containerProviderId": str,
-        "containerProviderType": Literal["EKS"],
-        "createdAfter": Union[datetime, str],
-        "createdBefore": Union[datetime, str],
-        "states": Sequence[VirtualClusterStateType],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListVirtualClustersRequestRequestTypeDef = TypedDict(
     "ListVirtualClustersRequestRequestTypeDef",
     {
@@ -572,46 +305,6 @@ ListVirtualClustersRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListVirtualClustersResponseTypeDef = TypedDict(
-    "ListVirtualClustersResponseTypeDef",
-    {
-        "virtualClusters": List["VirtualClusterTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-MonitoringConfigurationTypeDef = TypedDict(
-    "MonitoringConfigurationTypeDef",
-    {
-        "persistentAppUI": PersistentAppUIType,
-        "cloudWatchMonitoringConfiguration": "CloudWatchMonitoringConfigurationTypeDef",
-        "s3MonitoringConfiguration": "S3MonitoringConfigurationTypeDef",
-    },
-    total=False,
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
 S3MonitoringConfigurationTypeDef = TypedDict(
     "S3MonitoringConfigurationTypeDef",
     {
@@ -619,66 +312,6 @@ S3MonitoringConfigurationTypeDef = TypedDict(
     },
 )
 
-_RequiredSparkSubmitJobDriverTypeDef = TypedDict(
-    "_RequiredSparkSubmitJobDriverTypeDef",
-    {
-        "entryPoint": str,
-    },
-)
-_OptionalSparkSubmitJobDriverTypeDef = TypedDict(
-    "_OptionalSparkSubmitJobDriverTypeDef",
-    {
-        "entryPointArguments": List[str],
-        "sparkSubmitParameters": str,
-    },
-    total=False,
-)
-
-
-class SparkSubmitJobDriverTypeDef(
-    _RequiredSparkSubmitJobDriverTypeDef, _OptionalSparkSubmitJobDriverTypeDef
-):
-    pass
-
-
-_RequiredStartJobRunRequestRequestTypeDef = TypedDict(
-    "_RequiredStartJobRunRequestRequestTypeDef",
-    {
-        "virtualClusterId": str,
-        "clientToken": str,
-        "executionRoleArn": str,
-        "releaseLabel": str,
-        "jobDriver": "JobDriverTypeDef",
-    },
-)
-_OptionalStartJobRunRequestRequestTypeDef = TypedDict(
-    "_OptionalStartJobRunRequestRequestTypeDef",
-    {
-        "name": str,
-        "configurationOverrides": "ConfigurationOverridesTypeDef",
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class StartJobRunRequestRequestTypeDef(
-    _RequiredStartJobRunRequestRequestTypeDef, _OptionalStartJobRunRequestRequestTypeDef
-):
-    pass
-
-
-StartJobRunResponseTypeDef = TypedDict(
-    "StartJobRunResponseTypeDef",
-    {
-        "id": str,
-        "name": str,
-        "arn": str,
-        "virtualClusterId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
@@ -695,6 +328,218 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+CancelJobRunResponseTypeDef = TypedDict(
+    "CancelJobRunResponseTypeDef",
+    {
+        "id": str,
+        "virtualClusterId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateManagedEndpointResponseTypeDef = TypedDict(
+    "CreateManagedEndpointResponseTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "arn": str,
+        "virtualClusterId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateVirtualClusterResponseTypeDef = TypedDict(
+    "CreateVirtualClusterResponseTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "arn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DeleteManagedEndpointResponseTypeDef = TypedDict(
+    "DeleteManagedEndpointResponseTypeDef",
+    {
+        "id": str,
+        "virtualClusterId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DeleteVirtualClusterResponseTypeDef = TypedDict(
+    "DeleteVirtualClusterResponseTypeDef",
+    {
+        "id": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StartJobRunResponseTypeDef = TypedDict(
+    "StartJobRunResponseTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "arn": str,
+        "virtualClusterId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ContainerInfoTypeDef = TypedDict(
+    "ContainerInfoTypeDef",
+    {
+        "eksInfo": EksInfoTypeDef,
+    },
+    total=False,
+)
+
+JobDriverTypeDef = TypedDict(
+    "JobDriverTypeDef",
+    {
+        "sparkSubmitJobDriver": SparkSubmitJobDriverTypeDef,
+    },
+    total=False,
+)
+
+_RequiredListJobRunsRequestListJobRunsPaginateTypeDef = TypedDict(
+    "_RequiredListJobRunsRequestListJobRunsPaginateTypeDef",
+    {
+        "virtualClusterId": str,
+    },
+)
+_OptionalListJobRunsRequestListJobRunsPaginateTypeDef = TypedDict(
+    "_OptionalListJobRunsRequestListJobRunsPaginateTypeDef",
+    {
+        "createdBefore": Union[datetime, str],
+        "createdAfter": Union[datetime, str],
+        "name": str,
+        "states": Sequence[JobRunStateType],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListJobRunsRequestListJobRunsPaginateTypeDef(
+    _RequiredListJobRunsRequestListJobRunsPaginateTypeDef,
+    _OptionalListJobRunsRequestListJobRunsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef = TypedDict(
+    "_RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
+    {
+        "virtualClusterId": str,
+    },
+)
+_OptionalListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef = TypedDict(
+    "_OptionalListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
+    {
+        "createdBefore": Union[datetime, str],
+        "createdAfter": Union[datetime, str],
+        "types": Sequence[str],
+        "states": Sequence[EndpointStateType],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef(
+    _RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef,
+    _OptionalListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef,
+):
+    pass
+
+
+ListVirtualClustersRequestListVirtualClustersPaginateTypeDef = TypedDict(
+    "ListVirtualClustersRequestListVirtualClustersPaginateTypeDef",
+    {
+        "containerProviderId": str,
+        "containerProviderType": Literal["EKS"],
+        "createdAfter": Union[datetime, str],
+        "createdBefore": Union[datetime, str],
+        "states": Sequence[VirtualClusterStateType],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+MonitoringConfigurationTypeDef = TypedDict(
+    "MonitoringConfigurationTypeDef",
+    {
+        "persistentAppUI": PersistentAppUIType,
+        "cloudWatchMonitoringConfiguration": CloudWatchMonitoringConfigurationTypeDef,
+        "s3MonitoringConfiguration": S3MonitoringConfigurationTypeDef,
+    },
+    total=False,
+)
+
+_RequiredContainerProviderTypeDef = TypedDict(
+    "_RequiredContainerProviderTypeDef",
+    {
+        "type": Literal["EKS"],
+        "id": str,
+    },
+)
+_OptionalContainerProviderTypeDef = TypedDict(
+    "_OptionalContainerProviderTypeDef",
+    {
+        "info": ContainerInfoTypeDef,
+    },
+    total=False,
+)
+
+
+class ContainerProviderTypeDef(
+    _RequiredContainerProviderTypeDef, _OptionalContainerProviderTypeDef
+):
+    pass
+
+
+ConfigurationOverridesTypeDef = TypedDict(
+    "ConfigurationOverridesTypeDef",
+    {
+        "applicationConfiguration": Sequence["ConfigurationTypeDef"],
+        "monitoringConfiguration": MonitoringConfigurationTypeDef,
+    },
+    total=False,
+)
+
+_RequiredCreateVirtualClusterRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateVirtualClusterRequestRequestTypeDef",
+    {
+        "name": str,
+        "containerProvider": ContainerProviderTypeDef,
+        "clientToken": str,
+    },
+)
+_OptionalCreateVirtualClusterRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateVirtualClusterRequestRequestTypeDef",
+    {
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateVirtualClusterRequestRequestTypeDef(
+    _RequiredCreateVirtualClusterRequestRequestTypeDef,
+    _OptionalCreateVirtualClusterRequestRequestTypeDef,
+):
+    pass
+
+
 VirtualClusterTypeDef = TypedDict(
     "VirtualClusterTypeDef",
     {
@@ -702,9 +547,164 @@ VirtualClusterTypeDef = TypedDict(
         "name": str,
         "arn": str,
         "state": VirtualClusterStateType,
-        "containerProvider": "ContainerProviderTypeDef",
+        "containerProvider": ContainerProviderTypeDef,
         "createdAt": datetime,
         "tags": Dict[str, str],
     },
     total=False,
 )
+
+_RequiredCreateManagedEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateManagedEndpointRequestRequestTypeDef",
+    {
+        "name": str,
+        "virtualClusterId": str,
+        "type": str,
+        "releaseLabel": str,
+        "executionRoleArn": str,
+        "clientToken": str,
+    },
+)
+_OptionalCreateManagedEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateManagedEndpointRequestRequestTypeDef",
+    {
+        "certificateArn": str,
+        "configurationOverrides": ConfigurationOverridesTypeDef,
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateManagedEndpointRequestRequestTypeDef(
+    _RequiredCreateManagedEndpointRequestRequestTypeDef,
+    _OptionalCreateManagedEndpointRequestRequestTypeDef,
+):
+    pass
+
+
+EndpointTypeDef = TypedDict(
+    "EndpointTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "arn": str,
+        "virtualClusterId": str,
+        "type": str,
+        "state": EndpointStateType,
+        "releaseLabel": str,
+        "executionRoleArn": str,
+        "certificateArn": str,
+        "certificateAuthority": CertificateTypeDef,
+        "configurationOverrides": ConfigurationOverridesTypeDef,
+        "serverUrl": str,
+        "createdAt": datetime,
+        "securityGroup": str,
+        "subnetIds": List[str],
+        "stateDetails": str,
+        "failureReason": FailureReasonType,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+JobRunTypeDef = TypedDict(
+    "JobRunTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "virtualClusterId": str,
+        "arn": str,
+        "state": JobRunStateType,
+        "clientToken": str,
+        "executionRoleArn": str,
+        "releaseLabel": str,
+        "configurationOverrides": ConfigurationOverridesTypeDef,
+        "jobDriver": JobDriverTypeDef,
+        "createdAt": datetime,
+        "createdBy": str,
+        "finishedAt": datetime,
+        "stateDetails": str,
+        "failureReason": FailureReasonType,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+_RequiredStartJobRunRequestRequestTypeDef = TypedDict(
+    "_RequiredStartJobRunRequestRequestTypeDef",
+    {
+        "virtualClusterId": str,
+        "clientToken": str,
+        "executionRoleArn": str,
+        "releaseLabel": str,
+        "jobDriver": JobDriverTypeDef,
+    },
+)
+_OptionalStartJobRunRequestRequestTypeDef = TypedDict(
+    "_OptionalStartJobRunRequestRequestTypeDef",
+    {
+        "name": str,
+        "configurationOverrides": ConfigurationOverridesTypeDef,
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class StartJobRunRequestRequestTypeDef(
+    _RequiredStartJobRunRequestRequestTypeDef, _OptionalStartJobRunRequestRequestTypeDef
+):
+    pass
+
+
+DescribeVirtualClusterResponseTypeDef = TypedDict(
+    "DescribeVirtualClusterResponseTypeDef",
+    {
+        "virtualCluster": VirtualClusterTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListVirtualClustersResponseTypeDef = TypedDict(
+    "ListVirtualClustersResponseTypeDef",
+    {
+        "virtualClusters": List[VirtualClusterTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeManagedEndpointResponseTypeDef = TypedDict(
+    "DescribeManagedEndpointResponseTypeDef",
+    {
+        "endpoint": EndpointTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListManagedEndpointsResponseTypeDef = TypedDict(
+    "ListManagedEndpointsResponseTypeDef",
+    {
+        "endpoints": List[EndpointTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeJobRunResponseTypeDef = TypedDict(
+    "DescribeJobRunResponseTypeDef",
+    {
+        "jobRun": JobRunTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListJobRunsResponseTypeDef = TypedDict(
+    "ListJobRunsResponseTypeDef",
+    {
+        "jobRuns": List[JobRunTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
